@@ -1,9 +1,11 @@
 #!/usr/bin/env python3
 
-from pyauditor import Record, Component, Score
 import datetime
+
 from tzlocal import get_localzone
 
+from pyauditor import Component, Record, Score
+
 
 def main():
     local_tz = get_localzone()
